@@ -4,11 +4,9 @@ import functools
 
 from flake8 import defaults
 from flake8.main import debug
-from flake8.main import vcs
 
 
-def register_preliminary_options(parser):
-    # type: (argparse.ArgumentParser) -> None
+def register_preliminary_options(parser: argparse.ArgumentParser) -> None:
     """Register the preliminary options on our OptionManager.
 
     The preliminary options include:
@@ -65,7 +63,7 @@ def register_preliminary_options(parser):
 class JobsArgument:
     """Type callback for the --jobs argument."""
 
-    def __init__(self, arg):  # type: (str) -> None
+    def __init__(self, arg: str) -> None:
         """Parse and validate the --jobs argument.
 
         :param str arg:
@@ -79,7 +77,7 @@ class JobsArgument:
             self.n_jobs = int(arg)
         else:
             raise argparse.ArgumentTypeError(
-                "{!r} must be 'auto' or an integer.".format(arg),
+                f"{arg!r} must be 'auto' or an integer.",
             )
 
     def __str__(self):
@@ -107,6 +105,7 @@ def register_default_options(option_manager):
     - ``--max-doc-length``
     - ``--indent-size``
     - ``--select``
+    - ``--extend-select``
     - ``--disable-noqa``
     - ``--show-source``
     - ``--statistics``
@@ -261,7 +260,7 @@ def register_default_options(option_manager):
         metavar="n",
         default=defaults.INDENT_SIZE,
         parse_from_config=True,
-        help="Number of spaces used for indentation (Default: %default)",
+        help="Number of spaces used for indentation (Default: %(default)s)",
     )
 
     add_option(
@@ -274,6 +273,18 @@ def register_default_options(option_manager):
         " For example, ``--select=E4,E51,W234``. (Default: %(default)s)",
     )
 
+    add_option(
+        "--extend-select",
+        metavar="errors",
+        default="",
+        parse_from_config=True,
+        comma_separated_list=True,
+        help=(
+            "Comma-separated list of errors and warnings to add to the list "
+            "of selected ones. For example, ``--extend-select=E4,E51,W234``."
+        ),
+    )
+
     add_option(
         "--disable-noqa",
         default=False,
@@ -322,14 +333,6 @@ def register_default_options(option_manager):
         help='Exit with status code "0" even if there are errors.',
     )
 
-    add_option(
-        "--install-hook",
-        action=vcs.InstallAction,
-        choices=vcs.choices(),
-        help="Install a hook that is run prior to a commit for the supported "
-        "version control system.",
-    )
-
     add_option(
         "-j",
         "--jobs",
